@@ -41,6 +41,19 @@ GroupActionsWindow::GroupActionsWindow(QWidget *parent, Group* group) :
 
     setWindowTitle(m_Group->Name);
 
+    m_ContactMenu = new QMenu(this);
+    QAction* action = new QAction(tr("Select all"), this);
+    connect(action, SIGNAL(triggered()), this, SLOT(SelectAllSlot()));
+    m_ContactMenu->addAction(action);
+    action = new QAction(tr("Deselect all"), this);
+    connect(action, SIGNAL(triggered()), this, SLOT(DeselectAllSlot()));
+    m_ContactMenu->addAction(action);
+    action = new QAction(tr("Remove contact"), this);
+    connect(action, SIGNAL(triggered()), this, SLOT(RemoveOneSlot()));
+    m_ContactMenu->addAction(action);
+
+    ui->tblContacts->setContextMenuPolicy(Qt::CustomContextMenu);
+    connect(ui->tblContacts, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(ContactMenuSlot(QPoint)));
     connect(ui->tblContacts, SIGNAL(cellDoubleClicked(int,int)), this, SLOT(ContactDoubleClick(int, int)));
     connect(ui->btnAdd, SIGNAL(clicked()), this, SLOT(AddContactSlot()));
     connect(ui->btnRemove, SIGNAL(clicked()), this, SLOT(RemoveSlot()));
@@ -149,12 +162,6 @@ void GroupActionsWindow::SendSlot()
 {
     QList<QString> toSend = GetSelectedNumbers();
     if (toSend.count() > 0){
-        /*if (CommonStatic::ConfirmMessage(this,
-                                         tr("Confirm send"),
-                                         QString(tr("Send %1 SMS to contacts from group %2?"))
-                                         .arg(toSend.count())
-                                         .arg(m_Group->Name)) == QMessageBox::Yes){
-        */
 #ifdef Q_WS_MAEMO_5
             QString strTo;
             foreach (QString n, toSend){
@@ -184,11 +191,11 @@ QList<QString> GroupActionsWindow::GetSelectedNumbers()
     return res;
 }
 
-void GroupActionsWindow::SelectAllContacts()
+void GroupActionsWindow::SelectAllContacts(bool select)
 {
     for (int i=0; i<ui->tblContacts->rowCount(); i++){
         QCheckBox* chk = (QCheckBox*)ui->tblContacts->cellWidget(i, 0);
-        chk->setChecked(true);
+        chk->setChecked(select);
     }
 }
 
@@ -222,3 +229,35 @@ void GroupActionsWindow::ContactDoubleClick(int row, int)
     QCheckBox* chk = (QCheckBox*)ui->tblContacts->cellWidget(row, 0);
     chk->setChecked(!chk->isChecked());
 }
+
+
+void GroupActionsWindow::ContactMenuSlot(QPoint point)
+{
+    m_ContactMenu->exec(mapToGlobal(point));
+}
+
+void GroupActionsWindow::SelectAllSlot()
+{
+    SelectAllContacts();
+}
+
+void GroupActionsWindow::DeselectAllSlot()
+{
+    SelectAllContacts(false);
+}
+
+void GroupActionsWindow::RemoveOneSlot()
+{
+    if (CommonStatic::ConfirmMessage(this,
+                                     tr("Confirm remove"),
+                                     QString(tr("Remove 1 contact from group %1?"))
+                                     .arg(m_Group->Name)) == QMessageBox::Yes){
+        QTableWidgetItem* lbl = (QTableWidgetItem*)ui->tblContacts->item(ui->tblContacts->currentRow(), 3);
+        if (lbl != NULL){
+            m_Group->Remove(lbl->text());
+            m_Group->SaveToDb();
+            PopulateContactsTable();
+            SelectAllContacts();
+        }
+    }
+}
