@@ -24,6 +24,9 @@
 #include <QMenuBar>
 #include <QMenu>
 #include <QTimer>
+#ifdef Q_WS_MAEMO_5
+#include "hildon-uri.h"
+#endif
 #include "commonstatic.h"
 #include "editgroupwindow.h"
 #include "groupactionswindow.h"
@@ -50,7 +53,18 @@ MainWindow::MainWindow(QWidget *parent) :
     menu->addAction(action);
 
     connect(ui->btnNewGroup, SIGNAL(clicked()), this, SLOT(NewGroupSlot()));
-    connect(ui->tblGroups, SIGNAL(itemClicked(QTableWidgetItem*)), this, SLOT(GroupClickedSlot(QTableWidgetItem*)));
+
+    m_GroupMenu = new QMenu(this);
+    action = new QAction(tr("Remove group"), this);
+    connect(action, SIGNAL(triggered()), this, SLOT(RemoveGroupSlot()));
+    m_GroupMenu->addAction(action);
+    action = new QAction(tr("Send SMS to group"), this);
+    connect(action, SIGNAL(triggered()), this, SLOT(SendSmsToGroupSlot()));
+    m_GroupMenu->addAction(action);
+
+    ui->tblGroups->setContextMenuPolicy(Qt::CustomContextMenu);
+    connect(ui->tblGroups, SIGNAL(cellClicked(int,int)), this, SLOT(GroupClickedSlot(int, int)));
+    connect(ui->tblGroups, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(GroupMenuSlot(QPoint)));
     OpenDB();
     PopulateGroupsTable();
 }
@@ -153,10 +167,9 @@ void MainWindow::PopulateGroupsTable()
     delete cImage;
 }
 
-void MainWindow::GroupClickedSlot(QTableWidgetItem*)
-{
-    QTableWidget* t = (QTableWidget*)sender();
-    Group* g = m_Groups.at(t->currentRow());
+void MainWindow::GroupClickedSlot(int row, int)
+{    
+    Group* g = m_Groups.at(row);
 
     GroupActionsWindow* frm = new GroupActionsWindow(this, g);
     frm->exec();
@@ -188,3 +201,38 @@ void MainWindow::TimerSlot()
 {
     CommonStatic::LoadContactsCache();
 }
+
+void MainWindow::GroupMenuSlot(QPoint point)
+{
+    m_GroupMenu->exec(mapToGlobal(point));
+}
+
+void MainWindow::SendSmsToGroupSlot()
+{
+#ifdef Q_WS_MAEMO_5
+    Group* g = m_Groups.at(ui->tblGroups->currentRow());
+    QString strTo;
+    foreach (GroupContact* gc, g->ContactsId){
+        if (!strTo.isEmpty())
+            strTo.append(", ");
+        strTo.append(gc->Number);
+    }
+
+    QUrl smsUrl((QString("sms:%1").arg(strTo)));
+    smsUrl.addQueryItem("body", "");
+    hildon_uri_open(smsUrl.toString().toStdString().c_str(),NULL,NULL);
+#endif
+
+}
+
+void MainWindow::RemoveGroupSlot()
+{
+    Group* g = m_Groups.at(ui->tblGroups->currentRow());
+    if (CommonStatic::ConfirmMessage(this,
+                                     tr("Confirm remove"),
+                                     QString(tr("Remove group %1?"))
+                                     .arg(g->Name)) == QMessageBox::Yes){
+        g->Delete();
+        PopulateGroupsTable();
+    }
+}
